[![codecov](https://codecov.io/gh/JorgeJuarezM/xpire/graph/badge.svg?token=ZL54DIVD0M)](https://codecov.io/gh/JorgeJuarezM/xpire)

# XPIRE – eXtended PYthon Interpreter for Retro Emulation

## Basic implementation of an Intel 8080 Emulator

Right now, the emulator is able to run simple 8080 binary programs. I will work on more complex features later.

For future releases, i expect to emulate another CPU / Machines and make this project extensible enough to handle this.

## Feel free to contribute or contact me about this project jjuarez007@gmail.com


https://github.com/user-attachments/assets/79b43232-25ed-473c-aa20-df3f69df9975

